const fs = require('fs');

const failureRateThreshold = THRESHOLD;
const failureCountThreshold = 50;


const filePath = process.argv[2]
const records = JSON.parse(fs.readFileSync(filePath).toString())
const messageDeliveryMap = {}

for(record of records) {
    if(!messageDeliveryMap[record.from]) {
        messageDeliveryMap[record.from] = {
            platformBotId: record.platformbotid,
            errors: {}
        };
    }

    if(record.messagestatus === 'delivered') {
        messageDeliveryMap[record.from].success = parseInt(record.count, 10);
    } else {
        messageDeliveryMap[record.from].errors[record.errorcode] = parseInt(record.count, 10)
    }
}

for(sender in messageDeliveryMap) {
    let totalErrors = 0; 
    for(errorcode in messageDeliveryMap[sender].errors) {
        totalErrors += messageDeliveryMap[sender].errors[errorcode]
    }
    const totalSuccesses = messageDeliveryMap[sender].success;
    const totalMessages = totalErrors + totalSuccesses
    const failureRate = (totalErrors / (totalErrors + totalSuccesses))
    if(failureRate >= failureRateThreshold && totalErrors >= failureCountThreshold) {
        console.log(`Sender ${sender} - platformBotId ${messageDeliveryMap[sender].platformBotId} - exceeded ${failureRateThreshold*100}% failure threshold. ${totalMessages} sent, ${totalErrors} failed, delivery failure rate: ${failureRate.toFixed(2)*100}%`);
        console.log(`Errorcodes: ${JSON.stringify(messageDeliveryMap[sender].errors)}`)
    }
}
