const request = require("request-promise-native");

const AMPLIFY_WEBHOOK_BASE_URL = "https://ia.botworx.ai/webhook/zapier/rss",
    CARE2_FEEDS_BASE_URL = "https://www.thepetitionsite.com/feeds";

async function init() {
    const highWaterMark = "2024-06-28 03:22:01Z";

    const feed = await getFeed("sponsored");

    if (feed && feed.petitions && Array.isArray(feed.petitions)) {
        await Promise.all(
            feed.petitions.map(async (petition) => {
                if (Date.parse(petition.pubDate) >= Date.parse(highWaterMark)) {
                    const webupdateMessage = {
                        contentType: "any",
                        sourceUrl: petition.link,
                        title: petition.title,
                        subtitle: petition.shortDescription,
                        ur: petition.imageURL,
                        keywords: [],
                        category: petition.category,
                        createdAt: petition.pubDate,
                        publishedAt: Date.parse(petition.pubDate),
                        petitionId: petition.petitionID
                    };

                    console.log(webupdateMessage, await ingestWebupdateMessage("care2_sponsored_petitions", webupdateMessage));
                }
            })
        );
    }
}

async function getFeed(feed = "") {
    if (!feed) {
        return { error: "Invalid Feed" };
    }
    const options = {
        url: `${CARE2_FEEDS_BASE_URL}/${feed}`,
        headers: {
            Accept: "application/json",
            "Content-Type": "application/json"
        },
        json: true
    };
    return await request.get(options);
}

async function ingestWebupdateMessage(contentId, webupdateMessage) {
    if (!contentId) {
        return { error: "Invalid Content Id" };
    }
    if (!webupdateMessage) {
        return { error: "Invalid Webupdate Message" };
    }
    if (!webupdateMessage.sourceUrl) {
        return { error: "Invalid Source Url" };
    }
    const options = {
        url: `${AMPLIFY_WEBHOOK_BASE_URL}/${contentId}`,
        headers: {
            Accept: "application/json",
            "Content-Type": "application/json"
        },
        json: webupdateMessage
    };
    return await request.post(options);
}

init();
